@@ -155,7 +155,8 @@ int main(int argc, char *argv[])
 	irreco_config_read_layouts_from_files(irreco_data);
 
 	/* Start Lirc daemon */
-	system("/etc/init.d/lirc start");
+	system("sudo /etc/init.d/lirc start");
+	system("sudo /etc/init.d/lirc reload");
 
 	/* Create link to background image dir. */
 	irreco_link_bg_image_dir();
@@ -174,7 +175,7 @@ int main(int argc, char *argv[])
 	}
 
 	/* Exit */
-	system("/etc/init.d/lirc stop");
+	system("sudo /etc/init.d/lirc stop");
 	irreco_data_free(irreco_data);
 	osso_deinitialize(osso_context);
 	irreco_webdb_finalize();
