@@ -147,6 +147,7 @@ static void irreco_lircdb_dlg_init(IrrecoLircdbDlg *self)
 	GtkTreeSelection *select;
 	GtkWidget *tree_view_frame;
 	GtkWidget *tree_view_pannable;
+	GtkWidget *tree_box;
 
 	IRRECO_ENTER
 
@@ -168,12 +169,13 @@ static void irreco_lircdb_dlg_init(IrrecoLircdbDlg *self)
 			  irreco_gtk_align(GTK_WIDGET(self->hbox),
 					   0, 0, 1, 1, 8, 8, 8, 8));
 	/* Create tree_view_hbox */
+	tree_box = gtk_hbox_new(FALSE, 2);
 	tree_view_pannable = hildon_pannable_area_new();
 
 	/* Create Treeview */
 	self->tree_store = gtk_tree_store_new(
 		N_COLUMNS, G_TYPE_STRING, G_TYPE_INT, G_TYPE_POINTER);
-	self->tree_view = GTK_TREE_VIEW(hildon_gtk_tree_view_new_with_model(0,
+	self->tree_view = GTK_TREE_VIEW(hildon_gtk_tree_view_new_with_model(1,
 		GTK_TREE_MODEL(self->tree_store)));
 
 	renderer = gtk_cell_renderer_text_new();
@@ -181,8 +183,11 @@ static void irreco_lircdb_dlg_init(IrrecoLircdbDlg *self)
 		NULL, renderer, "text", TEXT_COL, NULL);
 	gtk_tree_view_append_column(self->tree_view, column);
 
+	gtk_box_pack_start(GTK_BOX(tree_box), GTK_WIDGET(self->tree_view),
+					   TRUE, TRUE, 0);
+
 	hildon_pannable_area_add_with_viewport(HILDON_PANNABLE_AREA(tree_view_pannable),
-					       GTK_WIDGET(self->tree_view));
+					       GTK_WIDGET(tree_box));
 
 	/* Create Frame for Treeview */
 	tree_view_frame = gtk_frame_new("");
